# _*_ coding: utf-8 _*_
#
# hspylib-kafman v0.9.65
#
# Package: main.kafman.views
"""Package initialization."""

__all__ = [
  'dialogs', 
  'indexes', 
  'main_qt_view', 
  'promotions'
]
__version__ = '0.9.65'
